==> webkit2gtk_2.24.2.orig.tar.xz: webkitgtk-2.24.2/Source/JavaScriptCore/bytecode/DeferredCompilationCallback.cpp <==
/*
 * Copyright (C) 2013-2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "DeferredCompilationCallback.h"

#include "CodeBlock.h"

namespace JSC {

DeferredCompilationCallback::DeferredCompilationCallback() { }
DeferredCompilationCallback::~DeferredCompilationCallback() { }

void DeferredCompilationCallback::compilationDidComplete(CodeBlock*, CodeBlock*, CompilationResult result)
{
    dumpCompiledSourcesIfNeeded();

    switch (result) {
    case CompilationFailed:
    case CompilationInvalidated:
    case CompilationSuccessful:
        break;
    case CompilationDeferred:
        RELEASE_ASSERT_NOT_REACHED();
    }
}

Vector<DeferredSourceDump>& DeferredCompilationCallback::ensureDeferredSourceDump()
{
    if (!m_deferredSourceDump)
        m_deferredSourceDump = std::make_unique<Vector<DeferredSourceDump>>();
    return *m_deferredSourceDump;
}

void DeferredCompilationCallback::dumpCompiledSourcesIfNeeded()
{
    if (!m_deferredSourceDump)
        return;

    ASSERT(Options::dumpSourceAtDFGTime());
    unsigned index = 0;
    for (auto& info : *m_deferredSourceDump) {
        dataLog("[", ++index, "] ");
        info.dump();
    }
    dataLog("\n");
}

} // JSC

==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/JavaScriptCore/bytecode/DeferredCompilationCallback.cpp <==
/*
 * Copyright (C) 2013-2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "DeferredCompilationCallback.h"

namespace JSC {

DeferredCompilationCallback::DeferredCompilationCallback() = default;
DeferredCompilationCallback::~DeferredCompilationCallback() = default;

void DeferredCompilationCallback::compilationDidComplete(CodeBlock*, CodeBlock*, CompilationResult result)
{
    dumpCompiledSourcesIfNeeded();

    switch (result) {
    case CompilationFailed:
    case CompilationInvalidated:
    case CompilationSuccessful:
        break;
    case CompilationDeferred:
        RELEASE_ASSERT_NOT_REACHED();
    }
}

Vector<DeferredSourceDump>& DeferredCompilationCallback::ensureDeferredSourceDump()
{
    if (!m_deferredSourceDump)
        m_deferredSourceDump = makeUnique<Vector<DeferredSourceDump>>();
    return *m_deferredSourceDump;
}

void DeferredCompilationCallback::dumpCompiledSourcesIfNeeded()
{
    if (!m_deferredSourceDump)
        return;

    ASSERT(Options::dumpSourceAtDFGTime());
    unsigned index = 0;
    for (auto& info : *m_deferredSourceDump) {
        dataLog("[", ++index, "] ");
        info.dump();
    }
    dataLog("\n");
}

} // JSC
